@@ -1,15 +1,10 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002-2004 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2004-2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2004,2005 John Tapsell <john@geola.co.uk>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2002-2004 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2004-2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2004, 2005 John Tapsell <john@geola.co.uk>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "transfer.h"
@@ -18,11 +13,13 @@
 #include "connectionmanager.h"
 #include "notificationhandler.h"
 #include "preferences.h"
-
-#include <KRun>
+#include "konversation_log.h"
 
 #include <config-konversation.h>
 
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
+
 #include <QFileInfo>
 
 namespace Konversation
@@ -32,7 +29,7 @@ namespace Konversation
         Transfer::Transfer(Type dccType, QObject *parent)
             : QObject(parent)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             m_type = dccType;
 
@@ -59,7 +56,7 @@ namespace Konversation
 
         Transfer::~Transfer()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
         }
 
         void Transfer::setConnectionId(int id)
@@ -80,7 +77,7 @@ namespace Konversation
 
         bool Transfer::queue()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             if (getStatus() != Configuring)
             {
                 return false;
@@ -104,7 +101,10 @@ namespace Konversation
         {
             if (getType() == Transfer::Send || getStatus() == Transfer::Done)
             {
-                new KRun(getFileURL(), 0);
+                auto *job = new KIO::OpenUrlJob(getFileURL());
+                job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+                job->setRunExecutables(false);
+                job->start();
             }
         }
 
@@ -135,9 +135,9 @@ namespace Konversation
 
         void Transfer::cleanUp()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             delete[] m_buffer;
-            m_buffer = 0;
+            m_buffer = nullptr;
             m_loggerTimer.stop();
         }
 
@@ -154,7 +154,7 @@ namespace Konversation
             Server *server = konv_app->getConnectionManager()->getServerByConnectionId(m_connectionId);
             if (server)
             {
-                qDebug() << "notification:" << errorMessage;
+                qCDebug(KONVERSATION_LOG) << "notification:" << errorMessage;
                 konv_app->notificationHandler()->dccError(server->getStatusView(), errorMessage);
             }
             setStatus(Failed, errorMessage);
@@ -178,7 +178,7 @@ namespace Konversation
                 Server *server = konv_app->getConnectionManager()->getServerByConnectionId(m_connectionId);
                 if (server)
                 {
-                    qDebug() << "notification:" << m_fileName;
+                    qCDebug(KONVERSATION_LOG) << "notification:" << m_fileName;
                     konv_app->notificationHandler()->dccTransferDone(server->getStatusView(), m_fileName, this);
                 }
             }
@@ -269,13 +269,12 @@ namespace Konversation
         QString Transfer::sanitizeFileName(const QString &fileName)
         {
             QString fileNameTmp = QFileInfo(fileName).fileName();
-            if (fileNameTmp.startsWith('.'))
-            {
-                fileNameTmp.replace(0, 1, '_');         // Don't create hidden files
+            if (fileNameTmp.startsWith(QLatin1Char('.'))) {
+                fileNameTmp.replace(0, 1, QLatin1Char('_'));         // Don't create hidden files
             }
             if (fileNameTmp.isEmpty())
             {
-                fileNameTmp = "unnamed";
+                fileNameTmp = QStringLiteral("unnamed");
             }
             return fileNameTmp;
         }
@@ -409,9 +408,8 @@ namespace Konversation
 
         QString Transfer::transferFileName(const QString & fileName)
         {
-            if (fileName.contains(' ') && !(fileName.startsWith('\"') && fileName.endsWith('\"')))
-            {
-                return '\"'+fileName+'\"';
+            if (fileName.contains(QLatin1Char(' ')) && !(fileName.startsWith(QLatin1Char('\"')) && fileName.endsWith(QLatin1Char('\"')))) {
+                return QLatin1Char('\"') + fileName + QLatin1Char('\"');
             }
 
             return fileName;
