@@ -1,20 +1,16 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009-2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009-2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "whiteboardcolorchooser.h"
 
+#include "konversation_log.h"
+
 #include <QPaintEvent>
 #include <QMouseEvent>
 #include <QPainter>
-#include <QDebug>
 #include <QColorDialog>
 #include <qdrawutil.h>
 
@@ -93,26 +89,26 @@ namespace Konversation
 
         void WhiteBoardColorChooser::mouseReleaseEvent(QMouseEvent *e)
         {
-            // qDebug() << "epos:"<< e->pos();
-            // qDebug() << "foregroundrect" << foregroundRect();
-            // qDebug() << "backgroundrect" << backgroundRect();
-            // qDebug() << "swap" << swapPixmapRect();
+            // qCDebug(KONVERSATION_LOG) << "epos:"<< e->pos();
+            // qCDebug(KONVERSATION_LOG) << "foregroundrect" << foregroundRect();
+            // qCDebug(KONVERSATION_LOG) << "backgroundrect" << backgroundRect();
+            // qCDebug(KONVERSATION_LOG) << "swap" << swapPixmapRect();
 
             ColorLayer whichColor = None;
 
             if (foregroundRect().contains(e->pos()))
             {
                 whichColor = ForegroundColor;
-                qDebug() << "> in foreground";
+                qCDebug(KONVERSATION_LOG) << "> in foreground";
             }
             else if (backgroundRect().contains(e->pos()))
             {
                 whichColor = BackgroundColor;
-                qDebug() << "> in background";
+                qCDebug(KONVERSATION_LOG) << "> in background";
             }
             else if (swapPixmapRect().contains(e->pos()))
             {
-                qDebug() << "> in swap";
+                qCDebug(KONVERSATION_LOG) << "> in swap";
                 QColor oldFore = m_foregroundColor;
                 m_foregroundColor = m_backgroundColor;
                 m_backgroundColor = oldFore;
@@ -123,8 +119,8 @@ namespace Konversation
 
             if (whichColor == ForegroundColor || whichColor == BackgroundColor)
             {
-                QColor col = color(whichColor);
-                if (QColorDialog::getColor(col, this) == QColorDialog::Accepted)
+                QColor col = QColorDialog::getColor(color(whichColor), this);
+                if (col.isValid())
                 {
                     setColor(whichColor, col);
                     update();
@@ -146,7 +142,7 @@ namespace Konversation
             tPaint.fillRect(bgRectInside, m_backgroundColor);
             qDrawShadePanel(&tPaint, bgRect, palette(),
                             false/*not sunken*/, 2/*lineWidth*/,
-                            0/*never fill*/);
+                            nullptr/*never fill*/);
 
             QRect fgRect = foregroundRect();
             QRect fgRectInside = QRect(fgRect.x () + 2, fgRect.y () + 2,
@@ -154,14 +150,15 @@ namespace Konversation
             tPaint.fillRect(fgRectInside, m_foregroundColor);
             qDrawShadePanel(&tPaint, fgRect, palette (),
                             false/*not sunken*/, 2/*lineWidth*/,
-                            0/*never fill*/);
+                            nullptr/*never fill*/);
 
             tPaint.end();
         }
 
         void WhiteBoardColorChooser::resizeEvent(QResizeEvent *e)
         {
-            Q_UNUSED(e);
+            Q_UNUSED(e)
+
             const int minWidthHeight = qMin(width(),height());
             const int swapImageSize = minWidthHeight/3;
             m_swapPixmap = QPixmap(swapImageSize, swapImageSize);
