@@ -150,7 +150,11 @@ QString ChatWindow::getURI(bool passNetwork)
 
     if (getType() == Channel)
     {
-        channel = getName().remove(QRegExp(QStringLiteral("^#")));
+        channel = getName();
+        if (channel.startsWith(QLatin1Char('#'))) {
+            channel.remove(0, 1);
+        }
+
         // must protect second #, but might as well protect all of them
         channel.replace(QLatin1String("#"), QLatin1String("%23"));
     }
